@@ -17,15 +17,14 @@ import os.path as osp
 
 # Third-party imports
 from qtpy.QtCore import Signal, Slot, QTimer
-from qtpy.QtCore import Slot, QTimer
 from qtpy.QtWidgets import QMessageBox
 
 # Local imports
 from spyder.api.config.decorators import on_conf_change
+from spyder.utils.installers import InstallerPylspError
 from spyder.config.base import (_, get_conf_path, running_under_pytest,
                                 running_in_mac_app)
 from spyder.config.lsp import PYTHON_CONFIG
-from spyder.config.manager import CONF
 from spyder.utils.misc import check_connection_port
 from spyder.plugins.completion.api import (SUPPORTED_LANGUAGES,
                                            SpyderCompletionProvider,
@@ -73,7 +72,7 @@ class LanguageServerProvider(SpyderCompletionProvider):
         ('pydocstyle/match', '(?!test_).*\\.py'),
         ('pydocstyle/match_dir', '[^\\.].*'),
         ('advanced/enabled', False),
-        ('advanced/module', 'pyls'),
+        ('advanced/module', 'pylsp'),
         ('advanced/host', '127.0.0.1'),
         ('advanced/port', 2087),
         ('advanced/external', False),
@@ -87,7 +86,7 @@ class LanguageServerProvider(SpyderCompletionProvider):
     #    want to *rename* options, then you need to do a MAJOR update in
     #    version, e.g. from 0.1.0 to 1.0.0
     # 3. You don't need to touch this value if you're just adding a new option
-    CONF_VERSION = "0.1.0"
+    CONF_VERSION = "0.2.0"
     CONF_TABS = TABS
 
     STOPPED = 'stopped'
@@ -218,6 +217,11 @@ class LanguageServerProvider(SpyderCompletionProvider):
         """
         Check if client or server for a given language are down.
         """
+        # This avoids an odd error when running our tests.
+        if running_under_pytest():
+            if not getattr(self, 'clients', None):
+                return
+
         client = self.clients[language]
         status = client['status']
         instance = client.get('instance', None)
@@ -250,6 +254,7 @@ class LanguageServerProvider(SpyderCompletionProvider):
         """
         Handle automatic restart of client/server on failure.
         """
+        InstallerPylspError(language)
         if (not self.clients_restarting.get(language, False)
                 and not running_under_pytest()):
             try:
@@ -695,7 +700,7 @@ class LanguageServerProvider(SpyderCompletionProvider):
         python_config = PYTHON_CONFIG.copy()
 
         # Server options
-        cmd = self.get_conf('advanced/module', 'pyls')
+        cmd = self.get_conf('advanced/module', 'pylsp')
         host = self.get_conf('advanced/host', '127.0.0.1')
         port = self.get_conf('advanced/port', 2087)
 
@@ -825,7 +830,7 @@ class LanguageServerProvider(SpyderCompletionProvider):
         python_config['host'] = host
         python_config['port'] = port
 
-        plugins = python_config['configurations']['pyls']['plugins']
+        plugins = python_config['configurations']['pylsp']['plugins']
         plugins['pycodestyle'].update(pycodestyle)
         plugins['pyflakes'].update(pyflakes)
         plugins['pydocstyle'].update(pydocstyle)
