@@ -639,7 +639,7 @@ def _url_handler(url, content_type="text/html"):
                 css_path = "static/css/light_pydoc.css"
 
             css_link = (
-                '<link rel="stylesheet" type="text/css" href="%s">' %
+                '<link rel="stylesheet" type="text/css" href="/%s">' %
                 css_path)
 
             code_style = (
@@ -914,6 +914,11 @@ def _start_server(urlhandler, hostname, port):
                 # for example when the client stops the load of the previously
                 # requested page. See spyder-ide/spyder#10755
                 pass
+            except BrokenPipeError:
+                # Needed to handle permission error when trying to open a port
+                # for the web server of the online help.
+                # See spyder-ide/spyder#13388
+                pass
 
         def log_message(self, *args):
             # Don't log messages.
