@@ -23,6 +23,7 @@ import time
 from itertools import islice
 
 # Third party imports
+from qtpy import PYQT5
 from qtpy.compat import getopenfilename, getsavefilename
 from qtpy.QtCore import QByteArray, QProcess, QProcessEnvironment, Qt, Signal
 from qtpy.QtGui import QColor
@@ -77,6 +78,15 @@ class ProfilerWidgetInformationToolbarSections:
     Main = 'main_section'
 
 
+class ProfilerWidgetMainToolbarItems:
+    FileCombo = 'file_combo'
+
+
+class ProfilerWidgetInformationToolbarItems:
+    Stretcher1 = 'stretcher_1'
+    Stretcher2 = 'stretcher_2'
+    DateLabel = 'date_label'
+
 # --- Utils
 # ----------------------------------------------------------------------------
 def is_profiler_installed():
@@ -170,9 +180,11 @@ class ProfilerWidget(PluginMainWidget):
 
         # Widgets
         self.process = None
-        self.filecombo = PythonModulesComboBox(self)
+        self.filecombo = PythonModulesComboBox(
+            self, id_=ProfilerWidgetMainToolbarItems.FileCombo)
         self.datatree = ProfilerDataTree(self)
         self.datelabel = QLabel()
+        self.datelabel.ID = ProfilerWidgetInformationToolbarItems.DateLabel
 
         # Layout
         layout = QVBoxLayout()
@@ -263,8 +275,12 @@ class ProfilerWidget(PluginMainWidget):
         secondary_toolbar = self.create_toolbar(
             ProfilerWidgetToolbars.Information)
         for item in [self.collapse_action, self.expand_action,
-                     self.create_stretcher(), self.datelabel,
-                     self.create_stretcher(), self.log_action,
+                     self.create_stretcher(
+                         id_=ProfilerWidgetInformationToolbarItems.Stretcher1),
+                     self.datelabel,
+                     self.create_stretcher(
+                         id_=ProfilerWidgetInformationToolbarItems.Stretcher2),
+                     self.log_action,
                      self.save_action, self.load_action, self.clear_action]:
             self.add_item_to_toolbar(
                 item,
@@ -648,7 +664,12 @@ class ProfilerDataTree(QTreeWidget, SpyderWidgetMixin):
     sig_edit_goto_requested = Signal(str, int, str)
 
     def __init__(self, parent=None):
-        super().__init__(parent, class_parent=parent)
+        if PYQT5:
+            super().__init__(parent, class_parent=parent)
+        else:
+            QTreeWidget.__init__(self, parent)
+            SpyderWidgetMixin.__init__(self, class_parent=parent)
+
         self.header_list = [_('Function/Module'), _('Total Time'), _('Diff'),
                             _('Local Time'), _('Diff'), _('Calls'), _('Diff'),
                             _('File:line')]
