@@ -44,21 +44,16 @@ from qtpy.QtWidgets import (QApplication, QCheckBox, QDialog, QGridLayout,
                             QMessageBox, QPushButton, QTableView,
                             QScrollBar, QTableWidget, QFrame,
                             QItemDelegate)
-from pandas import DataFrame, Index, Series, isna
-try:
-    from pandas._libs.tslib import OutOfBoundsDatetime
-except ImportError:  # For pandas version < 0.20
-    from pandas.tslib import OutOfBoundsDatetime
-import numpy as np
+from spyder_kernels.utils.lazymodules import numpy as np, pandas as pd
 
 # Local imports
+from spyder.api.config.mixins import SpyderConfigurationAccessor
 from spyder.config.base import _
 from spyder.config.fonts import DEFAULT_SMALL_DELTA
 from spyder.config.gui import get_font
-from spyder.config.manager import CONF
 from spyder.py3compat import (io, is_text_string, is_type_text_string, PY2,
                               to_text_string, perf_counter)
-from spyder.utils import icon_manager as ima
+from spyder.utils.icon_manager import ima
 from spyder.utils.qthelpers import (add_actions, create_action,
                                     keybinding, qapplication)
 from spyder.plugins.variableexplorer.widgets.arrayeditor import get_idx_rect
@@ -111,7 +106,8 @@ def global_max(col_vals, index):
 
 
 class DataFrameModel(QAbstractTableModel):
-    """ DataFrame Table Model.
+    """
+    DataFrame Table Model.
 
     Partly based in ExtDataModel and ExtFrameModel classes
     of the gtabview project.
@@ -291,7 +287,7 @@ class DataFrameModel(QAbstractTableModel):
         if not self.bgcolor_enabled:
             return
         value = self.get_value(index.row(), column)
-        if self.max_min_col[column] is None or isna(value):
+        if self.max_min_col[column] is None or pd.isna(value):
             color = QColor(BACKGROUND_NONNUMBER_COLOR)
             if is_text_string(value):
                 color.setAlphaF(BACKGROUND_STRING_ALPHA)
@@ -323,7 +319,7 @@ class DataFrameModel(QAbstractTableModel):
         # handling, so fallback uses iloc
         try:
             value = self.df.iat[row, column]
-        except OutOfBoundsDatetime:
+        except pd._libs.tslib.OutOfBoundsDatetime:
             value = self.df.iloc[:, column].astype(str).iat[row]
         except:
             value = self.df.iloc[row, column]
@@ -366,6 +362,10 @@ class DataFrameModel(QAbstractTableModel):
                          "an error ocurred while trying to do it")
         return to_qvariant()
 
+    def recalculate_index(self):
+        """Recalcuate index information."""
+        self.df_index_list = self.df.index.tolist()
+
     def sort(self, column, order=Qt.AscendingOrder):
         """Overriding sort method"""
         if self.complex_intran is not None:
@@ -397,6 +397,8 @@ class DataFrameModel(QAbstractTableModel):
                     QMessageBox.critical(self.dialog, "Error",
                                          "SystemError: %s" % to_text_string(e))
             else:
+                # Update index list
+                self.recalculate_index()
                 # To sort by index
                 self.df.sort_index(inplace=True, ascending=ascending)
         except TypeError as e:
@@ -506,13 +508,12 @@ class DataFrameModel(QAbstractTableModel):
         self.endResetModel()
 
 
-class DataFrameView(QTableView):
+class DataFrameView(QTableView, SpyderConfigurationAccessor):
     """
     Data Frame view class.
 
     Signals
     -------
-    sig_option_changed(): Raised after a sort by column.
     sig_sort_by_column(): Raised after more columns are fetched.
     sig_fetch_more_rows(): Raised after more rows are fetched.
     """
@@ -520,6 +521,8 @@ class DataFrameView(QTableView):
     sig_fetch_more_columns = Signal()
     sig_fetch_more_rows = Signal()
 
+    CONF_SECTION = 'variable_explorer'
+
     def __init__(self, parent, model, header, hscroll, vscroll):
         """Constructor."""
         QTableView.__init__(self, parent)
@@ -533,11 +536,7 @@ class DataFrameView(QTableView):
         self.header_class = header
         self.header_class.sectionClicked.connect(self.sortByColumn)
         self.menu = self.setup_menu()
-        CONF.config_shortcut(
-            self.copy,
-            context='variable_explorer',
-            name='copy',
-            parent=self)
+        self.config_shortcut(self.copy, 'copy', self)
         self.horizontalScrollBar().valueChanged.connect(
             self._load_more_columns)
         self.verticalScrollBar().valueChanged.connect(self._load_more_rows)
@@ -580,7 +579,6 @@ class DataFrameView(QTableView):
         if self.sort_old == [None]:
             self.header_class.setSortIndicatorShown(True)
         sort_order = self.header_class.sortIndicatorOrder()
-        self.sig_sort_by_column.emit()
         if not self.model().sort(index, sort_order):
             if len(self.sort_old) != 2:
                 self.header_class.setSortIndicatorShown(False)
@@ -589,6 +587,7 @@ class DataFrameView(QTableView):
                                                    self.sort_old[1])
             return
         self.sort_old = [index, self.header_class.sortIndicatorOrder()]
+        self.sig_sort_by_column.emit()
 
     def contextMenuEvent(self, event):
         """Reimplement Qt method."""
@@ -639,7 +638,7 @@ class DataFrameView(QTableView):
         try:
             obj.to_csv(output, sep='\t', index=index, header=header)
         except UnicodeEncodeError:
-            # Needed to handle enconding errors in Python 2
+            # Needed to handle encoding errors in Python 2
             # See spyder-ide/spyder#4833
             QMessageBox.critical(
                 self,
@@ -750,7 +749,7 @@ class DataFrameHeaderModel(QAbstractTableModel):
         """Get the information to put in the header."""
         if role == Qt.TextAlignmentRole:
             if orientation == Qt.Horizontal:
-                return Qt.AlignCenter | Qt.AlignBottom
+                return Qt.AlignCenter
             else:
                 return Qt.AlignRight | Qt.AlignVCenter
         if role != Qt.DisplayRole and role != Qt.ToolTipRole:
@@ -842,7 +841,7 @@ class DataFrameLevelModel(QAbstractTableModel):
         """
         if role == Qt.TextAlignmentRole:
             if orientation == Qt.Horizontal:
-                return Qt.AlignCenter | Qt.AlignBottom
+                return Qt.AlignCenter
             else:
                 return Qt.AlignRight | Qt.AlignVCenter
         if role != Qt.DisplayRole and role != Qt.ToolTipRole:
@@ -879,23 +878,19 @@ class DataFrameLevelModel(QAbstractTableModel):
         return None
 
 
-class DataFrameEditor(BaseDialog):
+class DataFrameEditor(BaseDialog, SpyderConfigurationAccessor):
     """
     Dialog for displaying and editing DataFrame and related objects.
 
     Based on the gtabview project (ExtTableView).
     For more information please see:
     https://github.com/wavexx/gtabview/blob/master/gtabview/viewer.py
-
-    Signals
-    -------
-    sig_option_changed(str, object): Raised if an option is changed.
-       Arguments are name of option and its new value.
     """
-    sig_option_changed = Signal(str, object)
+    CONF_SECTION = 'variable_explorer'
 
     def __init__(self, parent=None):
-        QDialog.__init__(self, parent)
+        super().__init__(parent)
+
         # Destroying the C++ object right after closing the dialog box,
         # otherwise it may be garbage-collected in another QThread
         # (e.g. the editor's analysis thread in Spyder), thus leading to
@@ -915,18 +910,17 @@ class DataFrameEditor(BaseDialog):
 
         self.layout = QGridLayout()
         self.layout.setSpacing(0)
-        self.layout.setContentsMargins(0, 0, 0, 0)
+        self.layout.setContentsMargins(20, 20, 20, 0)
         self.setLayout(self.layout)
-        self.setWindowIcon(ima.icon('arredit'))
         if title:
             title = to_text_string(title) + " - %s" % data.__class__.__name__
         else:
             title = _("%s editor") % data.__class__.__name__
-        if isinstance(data, Series):
+        if isinstance(data, pd.Series):
             self.is_series = True
             data = data.to_frame()
-        elif isinstance(data, Index):
-            data = DataFrame(data)
+        elif isinstance(data, pd.Index):
+            data = pd.DataFrame(data)
 
         self.setWindowTitle(title)
 
@@ -965,14 +959,16 @@ class DataFrameEditor(BaseDialog):
         # Make the dialog act as a window
         self.setWindowFlags(Qt.Window)
         btn_layout = QHBoxLayout()
+        btn_layout.setSpacing(5)
 
-        btn = QPushButton(_("Format"))
+        btn_format = QPushButton(_("Format"))
         # disable format button for int type
-        btn_layout.addWidget(btn)
-        btn.clicked.connect(self.change_format)
-        btn = QPushButton(_('Resize'))
-        btn_layout.addWidget(btn)
-        btn.clicked.connect(self.resize_to_contents)
+        btn_layout.addWidget(btn_format)
+        btn_format.clicked.connect(self.change_format)
+
+        btn_resize = QPushButton(_('Resize'))
+        btn_layout.addWidget(btn_resize)
+        btn_resize.clicked.connect(self.resize_to_contents)
 
         bgcolor = QCheckBox(_('Background color'))
         bgcolor.setChecked(self.dataModel.bgcolor_enabled)
@@ -1000,11 +996,14 @@ class DataFrameEditor(BaseDialog):
         self.btn_close.clicked.connect(self.reject)
         btn_layout.addWidget(self.btn_close)
 
-        btn_layout.setContentsMargins(4, 4, 4, 4)
+        btn_layout.setContentsMargins(0, 16, 0, 16)
         self.layout.addLayout(btn_layout, 4, 0, 1, 2)
         self.setModel(self.dataModel)
         self.resizeColumnsToContents()
 
+        format = '%' + self.get_conf('dataframe_format')
+        self.dataModel.set_format(format)
+
         return True
 
     @Slot(QModelIndex, QModelIndex)
@@ -1284,9 +1283,6 @@ class DataFrameEditor(BaseDialog):
     def change_format(self):
         """
         Ask user for display format for floats and use it.
-
-        This function also checks whether the format is valid and emits
-        `sig_option_changed`.
         """
         format, valid = QInputDialog.getText(self, _('Format'),
                                              _("Float formatting"),
@@ -1305,7 +1301,9 @@ class DataFrameEditor(BaseDialog):
                 QMessageBox.critical(self, _("Error"), msg)
                 return
             self.dataModel.set_format(format)
-            self.sig_option_changed.emit('dataframe_format', format)
+
+            format = format[1:]
+            self.set_conf('dataframe_format', format)
 
     def get_value(self):
         """Return modified Dataframe -- this is *not* a copy"""
@@ -1338,6 +1336,8 @@ class DataFrameEditor(BaseDialog):
 
         Uses the model of the dataTable as the base.
         """
+        # Update index list calculation
+        self.dataModel.recalculate_index()
         self.setModel(self.dataTable.model())
 
     def _fetch_more_columns(self):
@@ -1378,31 +1378,32 @@ def test():
     from numpy import nan
     from pandas.util.testing import assert_frame_equal, assert_series_equal
 
-    df1 = DataFrame([
-                     [True, "bool"],
-                     [1+1j, "complex"],
-                     ['test', "string"],
-                     [1.11, "float"],
-                     [1, "int"],
-                     [np.random.rand(3, 3), "Unkown type"],
-                     ["Large value", 100],
-                     ["áéí", "unicode"]
-                    ],
-                    index=['a', 'b', nan, nan, nan, 'c',
-                           "Test global max", 'd'],
-                    columns=[nan, 'Type'])
+    df1 = pd.DataFrame(
+        [
+            [True, "bool"],
+            [1+1j, "complex"],
+            ['test', "string"],
+            [1.11, "float"],
+            [1, "int"],
+            [np.random.rand(3, 3), "Unkown type"],
+            ["Large value", 100],
+            ["áéí", "unicode"]
+        ],
+        index=['a', 'b', nan, nan, nan, 'c', "Test global max", 'd'],
+        columns=[nan, 'Type']
+    )
     out = test_edit(df1)
     assert_frame_equal(df1, out)
 
-    result = Series([True, "bool"], index=[nan, 'Type'], name='a')
+    result = pd.Series([True, "bool"], index=[nan, 'Type'], name='a')
     out = test_edit(df1.iloc[0])
     assert_series_equal(result, out)
 
-    df1 = DataFrame(np.random.rand(100100, 10))
+    df1 = pd.DataFrame(np.random.rand(100100, 10))
     out = test_edit(df1)
     assert_frame_equal(out, df1)
 
-    series = Series(np.arange(10), name=0)
+    series = pd.Series(np.arange(10), name=0)
     out = test_edit(series)
     assert_series_equal(series, out)
 
